@@ -7,7 +7,6 @@ from torch.utils.data import DataLoader, random_split
 from torch.optim import Adam
 
 
-
 class Module(ABC, nn.Module):
     def __init__(self):
         super().__init__()
@@ -21,15 +20,13 @@ class Module(ABC, nn.Module):
         pass
 
     @abstractmethod
-    def forward(self, x: torch.Tensor, y: torch.Tensor):
+    def forward(self, x, y):
         """
-	  input: x: torch.Tensor, y: torch.Tensor
-        return: dict: {"scores":, "loss": }
+        :return: dict {"loss": , "scores", ...}
         """
         pass
 
 
-
 def make_reproducible(seed: int = 1):
     """
     ensures reproducibility over multiple script runs and after restarting the local machine
@@ -48,7 +45,6 @@ def make_reproducible(seed: int = 1):
     print("reproducible with seed", seed)
 
 
-
 class TrainerSetup:
     def __init__(self):
         self.device = "cpu"
@@ -85,7 +81,7 @@ class Trainer:
         return module(x=x, y=y)
 
     def train_batch(self, module: Module, adam: Adam, batch: list, freeze_pretrained_layers: bool):
-        # freeze/unfreeze here: longer runtime, better milan_kalkenings encapsulation
+        # freeze/unfreeze here: longer runtime, better encapsulation
         if freeze_pretrained_layers:
             module.freeze_pretrained_layers()
         else:
@@ -132,29 +128,11 @@ class Trainer:
         scores = self.forward_batch(module=module, batch=batch)["scores"]
         return torch.argmax(scores, dim=1)
 
-    def accuracy_epoch_eval(self, module: Module, loader_eval: DataLoader):
-        module.eval()
-        correct_sum = 0
-        obs_sum = 0
-        for batch in loader_eval:
-            with torch.no_grad():
-                x, y = batch
-                y = y.to(self.device)
-
-                preds = self.predict_class_labels_batch(module=module, batch=batch)
-                correct_sum += (y == preds).sum()
-                obs_sum += len(y)
-        return float(correct_sum / obs_sum)
-
-    def accuracies_epoch_eval(self, module: Module):
-        accuracy_epoch_train = self.accuracy_epoch_eval(module=module, loader_eval=self.loader_train)
-        accuracy_epoch_val = self.accuracy_epoch_eval(module=module, loader_eval=self.loader_val)
-        return accuracy_epoch_train, accuracy_epoch_val
-
-    def accuracies_losses_epoch_eval(self, module: Module):
-        accuracy_train, accuracy_val = self.accuracies_epoch_eval(module=module)
-        loss_train, loss_val = self.losses_epoch_eval(module=module)
-        return accuracy_train, accuracy_val, loss_train, loss_val
+    def overfit_one_train_batch(self, module: Module, batch: list, adam: Adam, n_iters: int, freeze_pretrained_layers: bool):
+        module.train()
+        for iter in range(n_iters):
+            self.train_batch(module=module, adam=adam, batch=batch, freeze_pretrained_layers=freeze_pretrained_layers)
+        return module
 
     def lrrt(self, freeze_pretrained_layers: bool):
         """
@@ -199,18 +177,18 @@ class Trainer:
         print("best loss slope", slope_best_total, "best lr", lr_best_total)
         return lr_best_total, slope_best_total
 
-    def train_n_epochs_early_stop_initial_lrrt(self, n_epochs: int, freeze_pretrained_layers: bool):
+    def train_n_epochs_early_stop_initial_lrrt(self, max_epochs: int, freeze_pretrained_layers: bool):
         """
         determines the initial learning rate per epoch using lrrt.
         early stops (naively after one early stop violation)
 
-        :param int n_epochs: number of training epochs after determining the initial learning rate with lrrt
+        :param int max_epochs: max #training epochs after determining the initial learning rate with lrrt
         :param bool freeze_pretrained_layers:
         :return: early stopped trained module
         """
         module = torch.load(self.checkpoint_running)
-        loss_val_last = self.loss_epoch_eval(module=module, loader_eval=self.loader_val)
-        print("initial eval loss val", loss_val_last)
+        loss_train, loss_val_last = self.losses_epoch_eval(module=module)
+        print("initial eval loss val", loss_val_last, "initial eval loss train", loss_train)
         for epoch in range(1, n_epochs + 1):
             print("training epoch", epoch)
             lr_best, _ = self.lrrt(freeze_pretrained_layers=freeze_pretrained_layers)
@@ -219,10 +197,8 @@ class Trainer:
             self.train_n_batches(module=module, adam=adam, n_batches=len(self.loader_train),
                                  freeze_pretrained_layers=freeze_pretrained_layers)
 
-            loss_val = self.loss_epoch_eval(module=module, loader_eval=self.loader_val)
-            accuracy_train, accuracy_val = self.accuracies_epoch_eval(module=module)
-            print("acc train", accuracy_train, "acc val", accuracy_val)
-            print("eval loss val", loss_val)
+            loss_train, loss_val = self.losses_epoch_eval(module=module)
+            print("eval loss val", loss_val, "eval loss train", loss_train)
             if loss_val < loss_val_last:
                 torch.save(module, self.checkpoint_running)
                 print("loss improvement achieved, running checkpoint updated")
